#
# PySNMP MIB module LMP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/LMP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:19:51 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ValueSizeConstraint, ConstraintsIntersection, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsIntersection", "ValueRangeConstraint")
( InterfaceIndexOrZero, ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndexOrZero", "ifIndex")
( InetAddressType, InetAddress, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddressType", "InetAddress")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, iso, ModuleIdentity, Counter32, Bits, Counter64, ObjectIdentity, transmission, TimeTicks, NotificationType, Gauge32, MibIdentifier, IpAddress, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "iso", "ModuleIdentity", "Counter32", "Bits", "Counter64", "ObjectIdentity", "transmission", "TimeTicks", "NotificationType", "Gauge32", "MibIdentifier", "IpAddress", "Integer32")
( DisplayString, TruthValue, RowStatus, StorageType, TimeStamp, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TruthValue", "RowStatus", "StorageType", "TimeStamp", "TextualConvention")
( teLinkIncomingIfId, teLinkRemoteIpAddr, TeLinkEncodingType, ) = mibBuilder.importSymbols("TE-LINK-STD-MIB", "teLinkIncomingIfId", "teLinkRemoteIpAddr", "TeLinkEncodingType")
lmpMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 227)).setRevisions(("2006-08-14 00:00", "2006-01-11 00:00",))
if mibBuilder.loadTexts: lmpMIB.setLastUpdated('200608140000Z')
if mibBuilder.loadTexts: lmpMIB.setOrganization('Common Control and Measurement Protocols (CCAMP)\n                 Working Group')
if mibBuilder.loadTexts: lmpMIB.setContactInfo('        Martin Dubuc\n        Email:  dubuc.consulting@sympatico.ca\n\n                Thomas D. Nadeau\n        Email:  tnadeau@cisco.com\n\n                Jonathan P. Lang\n        Email:  jplang@ieee.org\n\n                Evan McGinnis\n        Email:  emcginnis@hammerheadsystems.com\n\n                Adrian Farrel\n        Email:  adrian@olddog.co.uk')
if mibBuilder.loadTexts: lmpMIB.setDescription("Copyright (C) 2006 The Internet Society.  This version of\n        the MIB module is part of RFC 4631; see the RFC itself\n        for full legal notices.\n\n        This MIB module contains managed object definitions for\n        the Link Management Protocol (LMP) as\n        defined in 'Link Management Protocol'.")
class LmpInterval(Unsigned32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(1,65535)

class LmpRetransmitInterval(Unsigned32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(1,4294967295)

class LmpNodeId(OctetString, TextualConvention):
    displayHint = '1d.1d.1d.1d'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(4,4)
    fixedLength = 4

lmpNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 227, 0))
lmpObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 227, 1))
lmpConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 227, 2))
lmpAdminStatus = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),)).clone('up')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpAdminStatus.setDescription('The desired operational status of LMP on the node.\n\n\n\n        Implementations should save the value of this object in\n        persistent memory so that it survives restarts or reboot.')
lmpOperStatus = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpOperStatus.setDescription('The actual operational status of LMP on the node.')
lmpNbrTable = MibTable((1, 3, 6, 1, 2, 1, 10, 227, 1, 3), )
if mibBuilder.loadTexts: lmpNbrTable.setDescription('This table specifies the neighbor node(s) to which control\n        channels may be established.')
lmpNbrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 227, 1, 3, 1), ).setIndexNames((0, "LMP-MIB", "lmpNbrNodeId"))
if mibBuilder.loadTexts: lmpNbrEntry.setDescription('An entry in this table is created by a LMP-enabled device for\n        every pair of nodes that can establish control channels.')
lmpNbrNodeId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 3, 1, 1), LmpNodeId())
if mibBuilder.loadTexts: lmpNbrNodeId.setDescription('This is a unique index for an entry in the LmpNbrTable.\n        This value represents the remote Node ID.')
lmpNbrRetransmitInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 3, 1, 2), LmpRetransmitInterval().clone(500)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpNbrRetransmitInterval.setDescription('This object specifies the initial retransmission interval that\n        is used for the retransmission of messages that require\n        acknowledgement.  This object, along with lmpNbrRetryLimit,\n        is used to implement the congestion-handling mechanism defined\n        in Section 10 of the Link Management Protocol specification,\n        which is based on RFC 2914.')
lmpNbrRetryLimit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 3, 1, 3), Unsigned32().clone(3)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpNbrRetryLimit.setDescription('This object specifies the maximum number of times a message\n        is transmitted without being acknowledged.  A value of 0 is used\n        to indicate that a node should never stop retransmission.\n        This object, along with lmpNbrRetransmitInterval, is\n        used to implement the congestion-handling mechanism as defined\n        in Section 10 of the Link Management Protocol specification,\n        which is based on RFC 2914.')
lmpNbrRetransmitDelta = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 3, 1, 4), Unsigned32().clone(1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpNbrRetransmitDelta.setDescription('This object governs the speed with which the sender increases\n        the retransmission interval, as explained in Section 10 of the\n        Link Management Protocol specification, which is based on\n        RFC 2914.  This value is a power used to express the\n        exponential backoff.  The ratio of two successive retransmission\n        intervals is (1 + Delta).')
lmpNbrAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 3, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpNbrAdminStatus.setDescription('The desired operational status of LMP to this remote node.')
lmpNbrOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 3, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpNbrOperStatus.setDescription('The actual operational status of LMP to this remote node.')
lmpNbrRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 3, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpNbrRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  None of the writable objects\n        in a row can be changed if the status is active(1).\n        All read-create objects must have valid and consistent\n        values before the row can be activated.')
lmpNbrStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 3, 1, 8), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpNbrStorageType.setDescription("The storage type for this conceptual row in the\n        lmpNbrTable.  Conceptual rows having the value\n        'permanent' need not allow write-access to any\n\n\n\n        columnar object in the row.")
lmpCcHelloIntervalDefault = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 4), LmpInterval()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpCcHelloIntervalDefault.setDescription('This object specifies the default value for the HelloInterval\n        parameter used in the Hello protocol keep-alive phase.  It\n        indicates how frequently LMP Hello messages will be sent.  It\n        is used as the default value for lmpCcHelloInterval.\n        Implementations should save the value of this object in\n        persistent memory so that it survives restarts or reboot.')
lmpCcHelloIntervalDefaultMin = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 5), LmpInterval()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpCcHelloIntervalDefaultMin.setDescription('This object specifies the default minimum value for the\n        HelloInterval parameter.  It is used as a default value\n        for lmpCcHelloIntervalMin.  Implementations should save the\n        value of this object in persistent memory so that it survives\n        restarts or reboot.')
lmpCcHelloIntervalDefaultMax = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 6), LmpInterval()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpCcHelloIntervalDefaultMax.setDescription('This object specifies the default maximum value for the\n        HelloInterval parameter.  It is used as a default value\n        for lmpCcHelloIntervalMax.  Implementations should save the\n        value of this object in persistent memory so that it survives\n        restarts or reboot.')
lmpCcHelloDeadIntervalDefault = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 7), LmpInterval()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpCcHelloDeadIntervalDefault.setDescription('This object specifies the default HelloDeadInterval parameter\n        to use in the Hello protocol keep-alive phase.  It indicates\n        how long a device should wait before declaring the control\n        channel dead.  The HelloDeadInterval parameter should be at\n        least three times the value of HelloInterval.  It is used as\n        a default value for lmpCcHelloDeadInterval.  Implementations\n        should save the value of this object in persistent memory so\n        that it survives restarts or reboot.')
lmpCcHelloDeadIntervalDefaultMin = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 8), LmpInterval()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpCcHelloDeadIntervalDefaultMin.setDescription('This object specifies the default minimum value for the\n        HelloDeadInterval parameter.  It is used as a default value\n        for lmpCcHelloDeadIntervalMin.  Implementations should save\n        the value of this object in persistent memory so that it\n        survives restarts or reboot.')
lmpCcHelloDeadIntervalDefaultMax = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 9), LmpInterval()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpCcHelloDeadIntervalDefaultMax.setDescription('This object specifies the default maximum value for the\n        HelloDeadInterval parameter.  It is used as a default value\n        for lmpCcHelloDeadIntervalMax.  Implementations should save the\n        value of this object in persistent memory so that it survives\n        restarts or reboot.')
lmpControlChannelTable = MibTable((1, 3, 6, 1, 2, 1, 10, 227, 1, 10), )
if mibBuilder.loadTexts: lmpControlChannelTable.setDescription('This table specifies LMP control channel information.')
lmpControlChannelEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1), ).setIndexNames((0, "LMP-MIB", "lmpCcId"))
if mibBuilder.loadTexts: lmpControlChannelEntry.setDescription('An entry in this table is created by an LMP-enabled device for\n        every control channel.  Whenever a new entry is created with\n        lmpCcIsIf set to true(1), a corresponding entry is\n        created in ifTable as well (see RFC 2863).')
lmpCcId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: lmpCcId.setDescription('This value represents the local control channel identifier.\n        The control channel identifier is a non-zero 32-bit number.')
lmpCcUnderlyingIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 2), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcUnderlyingIfIndex.setDescription("If lmpCcIsIf is set to true(1), this object carries the\n        index into the ifTable of the entry that represents the\n        LMP interface over which LMP will transmit its traffic.\n        If this object is set to zero but lmpCcIsIf is set to\n        true(1), the control channel is not currently associated\n        with any underlying interface, and the control channel's\n        operational status must not be up(1); nor should the\n        control channel forward or receive traffic.\n        If lmpCcIsIf is set to false(2), this object should be set\n        to zero and ignored.")
lmpCcIsIf = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 3), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcIsIf.setDescription('In implementations where the control channels are modeled\n        as interfaces, the value of this object is true(1), and\n        this control channel is represented by an interface in\n        the interfaces group table as indicated by the value of\n        lmpCcUnderlyingIfIndex.  If control channels are not\n        modeled as interfaces, the value of this object is\n        false(2), and there is no corresponding interface for\n        this control channel in the interfaces group table;\n        the value of lmpCcUnderlyingIfIndex should be\n        ignored.')
lmpCcNbrNodeId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 4), LmpNodeId()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcNbrNodeId.setDescription('This is the Node ID of the control channel remote node.\n        This value either is configured or gets created by the node\n        when a Config message is received or when an outgoing Config\n        message is acknowledged by the remote node.')
lmpCcRemoteId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 5), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcRemoteId.setDescription('This value represents the remote control channel identifier\n        (32-bit number).  It is determined during the negotiation\n        phase.  A value of zero means that the remote control channel\n        identifier has not yet been learned.')
lmpCcRemoteAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 6), InetAddressType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcRemoteAddressType.setDescription('This value represents the remote control channel IP address\n        type.  In point-to-point configuration, this value can be set\n        to unknown(0).')
lmpCcRemoteIpAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 7), InetAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcRemoteIpAddr.setDescription('This value represents the remote control channel Internet\n        address for numbered control channel.  The type of this\n        address is determined by lmpCcRemoteAddressType.\n        The control channel must be numbered on non-point-to-point\n        configuration.  For point-to-point configuration, the\n        remote control channel address can be of type unknown,\n        in which case this object must be a zero-length string.  The\n        lmpCcRemoteId object then identifies the unnumbered\n        address.')
lmpCcSetupRole = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("active", 1), ("passive", 2),)).clone('active')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcSetupRole.setDescription('The role that this node should take during establishment\n        of this control channel.  An active node will initiate\n        establishment.  A passive node will wait for the remote node\n        to initiate.  A pair of nodes that both take the passive role\n        will never establish communications.')
lmpCcAuthentication = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 9), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcAuthentication.setDescription('This object indicates whether the control channel must use\n        authentication.')
lmpCcHelloInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 10), LmpInterval()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcHelloInterval.setDescription('This object specifies the value of the HelloInterval\n        parameter.  The default value for this object should be\n        set to lmpCcHelloIntervalDefault.')
lmpCcHelloIntervalMin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 11), LmpInterval()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcHelloIntervalMin.setDescription('This object specifies the minimum value for the\n        HelloInterval parameter.  The default value for this\n        object should be set to lmpCcHelloIntervalMinDefault.')
lmpCcHelloIntervalMax = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 12), LmpInterval()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcHelloIntervalMax.setDescription('This object specifies the maximum value for the\n        HelloInterval parameter.  The default value for this\n        object should be set to lmpCcHelloIntervalMaxDefault.')
lmpCcHelloIntervalNegotiated = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 13), LmpInterval()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcHelloIntervalNegotiated.setDescription('Once the control channel is active, this object represents\n        the negotiated HelloInterval value.')
lmpCcHelloDeadInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 14), LmpInterval()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcHelloDeadInterval.setDescription('This object specifies the value of the HelloDeadInterval\n        parameter.  The default value for this object should be\n        set to lmpCcHelloDeadIntervalDefault.')
lmpCcHelloDeadIntervalMin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 15), LmpInterval()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcHelloDeadIntervalMin.setDescription('This object specifies the minimum value for the\n        HelloDeadInterval parameter.  The default value for this\n        object should be set to lmpCcHelloDeadIntervalMinDefault.')
lmpCcHelloDeadIntervalMax = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 16), LmpInterval()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcHelloDeadIntervalMax.setDescription('This object specifies the maximum value for the\n        HelloDeadInterval parameter.  The default value for this\n        object should be set to lmpCcHelloIntervalMaxDefault.')
lmpCcHelloDeadIntervalNegotiated = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 17), LmpInterval()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcHelloDeadIntervalNegotiated.setDescription('Once the control channel is active, this object represents\n        the negotiated HelloDeadInterval value.')
lmpCcLastChange = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 18), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcLastChange.setDescription('The value of sysUpTime at the time the control channel entered\n        its current operational state.  If the current state was\n        entered prior to the last re-initialization of the local\n        network management subsystem, then this object contains a\n        zero value.')
lmpCcAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 19), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcAdminStatus.setDescription('The desired operational status of this control channel.')
lmpCcOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 20), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("up", 1), ("down", 2), ("configSnd", 3), ("configRcv", 4), ("active", 5), ("goingDown", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcOperStatus.setDescription('The actual operational status of this control channel.')
lmpCcRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 21), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  None of the writable objects\n        in a row can be changed if the status is active(1).\n        All read-create objects must have valid and consistent\n        values before the row can be activated.')
lmpCcStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 10, 1, 22), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpCcStorageType.setDescription("The storage type for this conceptual row in the\n        lmpControlChannelTable.  Conceptual rows having the value\n        'permanent' need not allow write-access to any\n        columnar object in the row.")
lmpControlChannelPerfTable = MibTable((1, 3, 6, 1, 2, 1, 10, 227, 1, 11), )
if mibBuilder.loadTexts: lmpControlChannelPerfTable.setDescription('This table specifies LMP control channel performance\n        counters.')
lmpControlChannelPerfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1), ).setIndexNames((0, "LMP-MIB", "lmpCcId"))
if mibBuilder.loadTexts: lmpControlChannelPerfEntry.setDescription('An entry in this table is created by a LMP-enabled device for\n        every control channel.  lmpCcCounterDiscontinuityTime is used\n        to indicate potential discontinuity for all counter objects\n        in this table.')
lmpCcInOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcInOctets.setDescription('The total number of LMP message octets received on the\n             control channel.')
lmpCcInDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcInDiscards.setDescription('The number of inbound packets that were chosen to be\n             discarded even though no errors had been detected.  One\n             possible reason for discarding such a packet could be to\n             free up buffer space.')
lmpCcInErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcInErrors.setDescription('The number of inbound packets that contained errors\n             preventing them from being processed by LMP.')
lmpCcOutOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcOutOctets.setDescription('The total number of LMP message octets transmitted out of\n             the control channel.')
lmpCcOutDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcOutDiscards.setDescription('The number of outbound packets that were chosen to be\n             discarded even though no errors had been detected to\n             prevent their being transmitted.  One possible reason\n             for discarding such a packet could be to free up buffer\n             space.')
lmpCcOutErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcOutErrors.setDescription('The number of outbound packets that could not be\n             transmitted because of errors.')
lmpCcConfigReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcConfigReceived.setDescription('This object counts the number of Config messages that have\n        been received on this control channel.')
lmpCcConfigSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcConfigSent.setDescription('This object counts the number of Config messages that have\n        been sent on this control channel.')
lmpCcConfigRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcConfigRetransmit.setDescription('This object counts the number of Config messages that\n        have been retransmitted over this control channel.')
lmpCcConfigAckReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcConfigAckReceived.setDescription('This object counts the number of ConfigAck messages that have\n        been received on this control channel.')
lmpCcConfigAckSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcConfigAckSent.setDescription('This object counts the number of ConfigAck messages that have\n        been sent on this control channel.')
lmpCcConfigNackReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcConfigNackReceived.setDescription('This object counts the number of ConfigNack messages that have\n        been received on this control channel.')
lmpCcConfigNackSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcConfigNackSent.setDescription('This object counts the number of ConfigNack messages that have\n        been sent on this control channel.')
lmpCcHelloReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcHelloReceived.setDescription('This object counts the number of Hello messages that have\n        been received on this control channel.')
lmpCcHelloSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcHelloSent.setDescription('This object counts the number of Hello messages that have\n        been sent on this control channel.')
lmpCcBeginVerifyReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcBeginVerifyReceived.setDescription('This object counts the number of BeginVerify messages that have\n        been received on this control channel.')
lmpCcBeginVerifySent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcBeginVerifySent.setDescription('This object counts the number of BeginVerify messages that have\n        been sent on this control channel.')
lmpCcBeginVerifyRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcBeginVerifyRetransmit.setDescription('This object counts the number of BeginVerify messages that\n        have been retransmitted over this control channel.')
lmpCcBeginVerifyAckReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcBeginVerifyAckReceived.setDescription('This object counts the number of BeginVerifyAck messages that\n        have been received on this control channel.')
lmpCcBeginVerifyAckSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 20), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcBeginVerifyAckSent.setDescription('This object counts the number of BeginVerifyAck messages that\n        have been sent on this control channel.')
lmpCcBeginVerifyNackReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 21), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcBeginVerifyNackReceived.setDescription('This object counts the number of BeginVerifyNack messages that\n        have been received on this control channel.')
lmpCcBeginVerifyNackSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 22), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcBeginVerifyNackSent.setDescription('This object counts the number of BeginVerifyNack messages that\n        have been sent on this control channel.')
lmpCcEndVerifyReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 23), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcEndVerifyReceived.setDescription('This object counts the number of EndVerify messages that have\n        been received on this control channel.')
lmpCcEndVerifySent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 24), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcEndVerifySent.setDescription('This object counts the number of EndVerify messages that have\n        been sent on this control channel.')
lmpCcEndVerifyRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 25), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcEndVerifyRetransmit.setDescription('This object counts the number of EndVerify messages that\n        have been retransmitted over this control channel.')
lmpCcEndVerifyAckReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 26), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcEndVerifyAckReceived.setDescription('This object counts the number of EndVerifyAck messages that\n        have been received on this control channel.')
lmpCcEndVerifyAckSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 27), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcEndVerifyAckSent.setDescription('This object counts the number of EndVerifyAck messages that\n        have been sent on this control channel.')
lmpCcTestStatusSuccessReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 28), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcTestStatusSuccessReceived.setDescription('This object counts the number of TestStatusSuccess messages\n        that have been received on this control channel.')
lmpCcTestStatusSuccessSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 29), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcTestStatusSuccessSent.setDescription('This object counts the number of TestStatusSuccess messages\n        that have been sent on this control channel.')
lmpCcTestStatusSuccessRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 30), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcTestStatusSuccessRetransmit.setDescription('This object counts the number of TestStatusSuccess messages\n        that have been retransmitted over this control channel.')
lmpCcTestStatusFailureReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 31), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcTestStatusFailureReceived.setDescription('This object counts the number of TestStatusFailure messages\n        that have been received on this control channel.')
lmpCcTestStatusFailureSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 32), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcTestStatusFailureSent.setDescription('This object counts the number of TestStatusFailure messages\n        that have been sent on this control channel.')
lmpCcTestStatusFailureRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 33), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcTestStatusFailureRetransmit.setDescription('This object counts the number of TestStatusFailure messages\n        that have been retransmitted over this control channel.')
lmpCcTestStatusAckReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 34), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcTestStatusAckReceived.setDescription('This object counts the number of TestStatusAck messages\n        that have been received on this control channel.')
lmpCcTestStatusAckSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 35), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcTestStatusAckSent.setDescription('This object counts the number of TestStatusAck messages\n        that have been sent on this control channel.')
lmpCcLinkSummaryReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 36), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcLinkSummaryReceived.setDescription('This object counts the number of LinkSummary messages\n        that have been received on this control channel.')
lmpCcLinkSummarySent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 37), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcLinkSummarySent.setDescription('This object counts the number of LinkSummary messages\n        that have been sent on this control channel.')
lmpCcLinkSummaryRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 38), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcLinkSummaryRetransmit.setDescription('This object counts the number of LinkSummary messages that\n        have been retransmitted over this control channel.')
lmpCcLinkSummaryAckReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 39), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcLinkSummaryAckReceived.setDescription('This object counts the number of LinkSummaryAck messages\n        that have been received on this control channel.')
lmpCcLinkSummaryAckSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 40), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcLinkSummaryAckSent.setDescription('This object counts the number of LinkSummaryAck messages\n        that have been sent on this control channel.')
lmpCcLinkSummaryNackReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 41), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcLinkSummaryNackReceived.setDescription('This object counts the number of LinkSummaryNack messages\n        that have been received on this control channel.')
lmpCcLinkSummaryNackSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 42), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcLinkSummaryNackSent.setDescription('This object counts the number of LinkSummaryNack messages\n        that have been sent on this control channel.')
lmpCcChannelStatusReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 43), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcChannelStatusReceived.setDescription('This object counts the number of ChannelStatus messages\n        that have been received on this control channel.')
lmpCcChannelStatusSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 44), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcChannelStatusSent.setDescription('This object counts the number of ChannelStatus messages\n        that have been sent on this control channel.')
lmpCcChannelStatusRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 45), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcChannelStatusRetransmit.setDescription('This object counts the number of ChannelStatus messages\n        that have been retransmitted on this control channel.')
lmpCcChannelStatusAckReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 46), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcChannelStatusAckReceived.setDescription('This object counts the number of ChannelStatusAck messages\n        that have been received on this control channel.')
lmpCcChannelStatusAckSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 47), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcChannelStatusAckSent.setDescription('This object counts the number of ChannelStatus messages\n        that have been sent on this control channel.')
lmpCcChannelStatusReqReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 48), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcChannelStatusReqReceived.setDescription('This object counts the number of ChannelStatusRequest messages\n        that have been received on this control channel.')
lmpCcChannelStatusReqSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 49), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcChannelStatusReqSent.setDescription('This object counts the number of ChannelStatusRequest messages\n        that have been sent on this control channel.')
lmpCcChannelStatusReqRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 50), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcChannelStatusReqRetransmit.setDescription('This object counts the number of ChannelStatusRequest messages\n        that have been retransmitted on this control channel.')
lmpCcChannelStatusRspReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 51), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcChannelStatusRspReceived.setDescription('This object counts the number of ChannelStatusResponse messages\n        that have been received on this control channel.')
lmpCcChannelStatusRspSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 52), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcChannelStatusRspSent.setDescription('This object counts the number of ChannelStatusResponse messages\n        that have been sent on this control channel.')
lmpCcCounterDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 11, 1, 53), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpCcCounterDiscontinuityTime.setDescription("The value of sysUpTime on the most recent occasion at which\n         one or more of this control channel's counters suffered a\n         discontinuity.  The relevant counters are the specific\n         instances associated with this control channel of any\n         Counter32 object contained in the lmpControlChannelPerfTable.\n         If no such discontinuities have occurred since the last re-\n         initialization of the local management subsystem, then this\n         object contains a zero value.")
lmpTeLinkTable = MibTable((1, 3, 6, 1, 2, 1, 10, 227, 1, 12), )
if mibBuilder.loadTexts: lmpTeLinkTable.setDescription('This table specifies the LMP-specific TE link information.\n        Overall TE link information is kept in three separate tables:\n        ifTable for interface-specific information, lmpTeLinkTable\n        for LMP specific information, and teLinkTable for generic\n        TE link information.  ifIndex is the common index to all\n        tables.')
lmpTeLinkEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 227, 1, 12, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: lmpTeLinkEntry.setDescription('An entry in this table exists for each ifEntry with an\n        ifType of teLink(200) that is managed by LMP.  An ifEntry with\n        an ifIndex must exist before the corresponding lmpTeLinkEntry is\n        created.  If a TE link entry in the ifTable is destroyed, then\n        so is the corresponding entry in the lmpTeLinkTable.  The\n        administrative status value is controlled from the ifEntry.\n        Setting the administrative status to testing prompts LMP to\n        start link verification on the TE link.  Information about the\n        TE link that is not LMP specific is contained in the\n        teLinkTable of the TE-LINK-STD-MIB MIB module.')
lmpTeLinkNbrRemoteNodeId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 12, 1, 1), LmpNodeId()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpTeLinkNbrRemoteNodeId.setDescription('This is the Node ID of the TE link remote node.  This value\n        may be learned during the control channel parameter negotiation\n\n\n\n        phase (in the Config message).  Node ID is an address whose\n        type must be IPv4.')
lmpTeLinkVerification = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 12, 1, 2), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpTeLinkVerification.setDescription('This object indicates whether the LMP link verification\n        procedure is enabled for this TE link.')
lmpTeLinkFaultManagement = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 12, 1, 3), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpTeLinkFaultManagement.setDescription('This object indicates whether the LMP fault management procedure\n        is enabled on this TE link.')
lmpTeLinkDwdm = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 12, 1, 4), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpTeLinkDwdm.setDescription('This object indicates whether the LMP DWDM procedure is enabled\n        on this TE link.')
lmpTeLinkOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 12, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("up", 1), ("down", 2), ("testing", 3), ("init", 4), ("degraded", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeLinkOperStatus.setDescription('The actual operational status of this TE link.  The status\n        is set to testing when the TE link is performing link\n        verification.  A degraded state indicates that there is\n\n\n\n        no active control channel between the pair of nodes that\n        form the endpoints of the TE link, but that at least one\n        data-bearing link on the TE link is allocated.')
lmpTeLinkRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 12, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpTeLinkRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  None of the writable objects\n        in a row can be changed if the status is active(1).\n        All read-create objects must have valid and consistent\n        values before the row can be activated.')
lmpTeLinkStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 12, 1, 7), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpTeLinkStorageType.setDescription("The storage type for this conceptual row in the\n        lmpTeLinkTable.  Conceptual rows having the value\n        'permanent' need not allow write-access to any\n        columnar object in the row.")
lmpGlobalLinkVerificationInterval = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 13), Unsigned32()).setUnits('milliseconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpGlobalLinkVerificationInterval.setDescription('This object indicates how often the link verification\n        procedure is executed.  The interval is in milliseconds.\n        A value of 0 is used to indicate that the link\n        verification procedure should not be executed.  The\n        interval specified in this object should be large enough\n        to allow the verification procedure to be completed\n        before the start of the next interval.\n        Implementations should save the value of this object in\n        persistent memory so that it survives restarts or reboot.')
lmpLinkVerificationTable = MibTable((1, 3, 6, 1, 2, 1, 10, 227, 1, 14), )
if mibBuilder.loadTexts: lmpLinkVerificationTable.setDescription('This table specifies TE link information associated with the\n        LMP verification procedure.')
lmpLinkVerificationEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 227, 1, 14, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: lmpLinkVerificationEntry.setDescription('An entry in this table is created by an LMP-enabled device for\n        every TE link that supports the LMP verification\n        procedure.')
lmpLinkVerifyInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 14, 1, 1), LmpInterval()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpLinkVerifyInterval.setDescription('This object specifies the VerifyInterval parameter used\n        in the LMP link verification process.  It indicates the\n        interval at which the Test messages are sent.')
lmpLinkVerifyDeadInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 14, 1, 2), LmpInterval()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpLinkVerifyDeadInterval.setDescription('This object specifies the VerifyDeadInterval parameter used\n        in the verification of the physical connectivity of data-\n        bearing links.  It specifies the observation period used to\n        detect a Test message at the remote node.')
lmpLinkVerifyTransportMechanism = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 14, 1, 3), Bits().clone(namedValues=NamedValues(("payload", 0), ("dccSectionOverheadBytes", 1), ("dccLineOverheadBytes", 2), ("j0Trace", 3), ("j1Trace", 4), ("j2Trace", 5),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpLinkVerifyTransportMechanism.setDescription('This defines the transport mechanism for the Test messages.  The\n        scope of this bit mask is restricted to each link encoding\n        type.  The local node will set the bits corresponding to the\n        various mechanisms it can support for transmitting LMP Test\n        messages.  The receiver chooses the appropriate mechanism in the\n        BeginVerifyAck message.')
lmpLinkVerifyAllLinks = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 14, 1, 4), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpLinkVerifyAllLinks.setDescription('A value of true(1) for this object indicates that the\n        verification process checks all unallocated links; otherwise,\n        only the new ports or component links that have been added to\n        this TE link are verified.')
lmpLinkVerifyTransmissionRate = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 14, 1, 5), Unsigned32()).setUnits('bytes per second').setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpLinkVerifyTransmissionRate.setDescription('This is the transmission rate of the data link over which\n        the Test messages will be transmitted and is expressed in\n        bytes per second.')
lmpLinkVerifyWavelength = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 14, 1, 6), Unsigned32()).setUnits('nanometers').setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpLinkVerifyWavelength.setDescription('This value corresponds to the wavelength at\n        which the Test messages will be transmitted and is\n        measured in nanometers (nm).  If each data-bearing link\n        corresponds to a separate wavelength, then this value should\n        be set to 0.')
lmpLinkVerifyRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 14, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpLinkVerifyRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  None of the writable objects\n        in a row can be changed if the status is active(1).\n        All read-create objects must have valid and consistent\n        values before the row can be activated.')
lmpLinkVerifyStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 14, 1, 8), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpLinkVerifyStorageType.setDescription("The storage type for this conceptual row in the\n        lmpLinkVerificationTable.  Conceptual rows having the value\n        'permanent' need not allow write-access to any\n\n\n\n        columnar object in the row.")
lmpTeLinkPerfTable = MibTable((1, 3, 6, 1, 2, 1, 10, 227, 1, 15), )
if mibBuilder.loadTexts: lmpTeLinkPerfTable.setDescription('This table specifies LMP TE link performance counters.')
lmpTeLinkPerfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: lmpTeLinkPerfEntry.setDescription('An entry in this table is created by an LMP-enabled device for\n        every TE link.  lmpTeCounterDiscontinuityTime is used\n        to indicate potential discontinuity for all counter objects\n        in this table.')
lmpTeInOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeInOctets.setDescription('The total number of LMP message octets received for\n             this TE link.')
lmpTeOutOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeOutOctets.setDescription('The total number of LMP message octets transmitted out\n             for this TE link.')
lmpTeBeginVerifyReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeBeginVerifyReceived.setDescription('This object counts the number of BeginVerify messages that have\n\n\n\n        been received for this TE link.')
lmpTeBeginVerifySent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeBeginVerifySent.setDescription('This object counts the number of BeginVerify messages that have\n        been sent for this TE link.')
lmpTeBeginVerifyRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeBeginVerifyRetransmit.setDescription('This object counts the number of BeginVerify messages that\n        have been retransmitted for this TE link.')
lmpTeBeginVerifyAckReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeBeginVerifyAckReceived.setDescription('This object counts the number of BeginVerifyAck messages that\n        have been received for this TE link.')
lmpTeBeginVerifyAckSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeBeginVerifyAckSent.setDescription('This object counts the number of BeginVerifyAck messages that\n        have been sent for this TE link.')
lmpTeBeginVerifyNackReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeBeginVerifyNackReceived.setDescription('This object counts the number of BeginVerifyNack messages that\n        have been received for this TE link.')
lmpTeBeginVerifyNackSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeBeginVerifyNackSent.setDescription('This object counts the number of BeginVerifyNack messages that\n        have been sent for this TE link.')
lmpTeEndVerifyReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeEndVerifyReceived.setDescription('This object counts the number of EndVerify messages that have\n        been received for this TE link.')
lmpTeEndVerifySent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeEndVerifySent.setDescription('This object counts the number of EndVerify messages that have\n        been sent for this TE link.')
lmpTeEndVerifyRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeEndVerifyRetransmit.setDescription('This object counts the number of EndVerify messages that\n        have been retransmitted over this control channel.')
lmpTeEndVerifyAckReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeEndVerifyAckReceived.setDescription('This object counts the number of EndVerifyAck messages that\n        have been received for this TE link.')
lmpTeEndVerifyAckSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeEndVerifyAckSent.setDescription('This object counts the number of EndVerifyAck messages that\n        have been sent for this TE link.')
lmpTeTestStatusSuccessReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeTestStatusSuccessReceived.setDescription('This object counts the number of TestStatusSuccess messages\n        that have been received for this TE link.')
lmpTeTestStatusSuccessSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeTestStatusSuccessSent.setDescription('This object counts the number of TestStatusSuccess messages\n        that have been sent for this TE link.')
lmpTeTestStatusSuccessRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeTestStatusSuccessRetransmit.setDescription('This object counts the number of TestStatusSuccess messages\n        that have been retransmitted for this TE link.')
lmpTeTestStatusFailureReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeTestStatusFailureReceived.setDescription('This object counts the number of TestStatusFailure messages\n        that have been received for this TE link.')
lmpTeTestStatusFailureSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeTestStatusFailureSent.setDescription('This object counts the number of TestStatusFailure messages\n\n\n\n        that have been sent for this TE link.')
lmpTeTestStatusFailureRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 20), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeTestStatusFailureRetransmit.setDescription('This object counts the number of TestStatusFailure messages\n        that have been retransmitted on this TE link.')
lmpTeTestStatusAckReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 21), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeTestStatusAckReceived.setDescription('This object counts the number of TestStatusAck messages that\n        have been received for this TE link.')
lmpTeTestStatusAckSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 22), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeTestStatusAckSent.setDescription('This object counts the number of TestStatusAck messages that\n        have been sent for this TE link.')
lmpTeLinkSummaryReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 23), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeLinkSummaryReceived.setDescription('This object counts the number of LinkSummary messages that\n        have been received for this TE link.')
lmpTeLinkSummarySent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 24), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeLinkSummarySent.setDescription('This object counts the number of LinkSummary messages that\n        have been sent for this TE link.')
lmpTeLinkSummaryRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 25), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeLinkSummaryRetransmit.setDescription('This object counts the number of LinkSummary messages that\n        have been retransmitted over this control channel.')
lmpTeLinkSummaryAckReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 26), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeLinkSummaryAckReceived.setDescription('This object counts the number of LinkSummaryAck messages that\n        have been received for this TE link.')
lmpTeLinkSummaryAckSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 27), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeLinkSummaryAckSent.setDescription('This object counts the number of LinkSummaryAck messages that\n        have been sent for this TE link.')
lmpTeLinkSummaryNackReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 28), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeLinkSummaryNackReceived.setDescription('This object counts the number of LinkSummaryNack messages that\n        have been received for this TE link.')
lmpTeLinkSummaryNackSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 29), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeLinkSummaryNackSent.setDescription('This object counts the number of LinkSummaryNack messages that\n        have been sent for this TE link.')
lmpTeChannelStatusReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 30), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeChannelStatusReceived.setDescription('This object counts the number of ChannelStatus messages that\n        have been received for this TE link.')
lmpTeChannelStatusSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 31), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeChannelStatusSent.setDescription('This object counts the number of ChannelStatus messages that\n        have been sent for this TE link.')
lmpTeChannelStatusRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 32), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeChannelStatusRetransmit.setDescription('This object counts the number of ChannelStatus messages that\n        have been retransmitted for this TE link.')
lmpTeChannelStatusAckReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 33), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeChannelStatusAckReceived.setDescription('This object counts the number of ChannelStatusAck messages\n        that have been received for this TE link.')
lmpTeChannelStatusAckSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 34), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeChannelStatusAckSent.setDescription('This object counts the number of ChannelStatus messages\n        that have been sent for this TE link.')
lmpTeChannelStatusReqReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 35), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeChannelStatusReqReceived.setDescription('This object counts the number of ChannelStatusRequest messages\n\n\n\n        that have been received for this TE link.')
lmpTeChannelStatusReqSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 36), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeChannelStatusReqSent.setDescription('This object counts the number of ChannelStatusRequest messages\n        that have been sent for this TE link.')
lmpTeChannelStatusReqRetransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 37), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeChannelStatusReqRetransmit.setDescription('This object counts the number of ChannelStatusRequest messages\n        that have been retransmitted for this TE link.')
lmpTeChannelStatusRspReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 38), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeChannelStatusRspReceived.setDescription('This object counts the number of ChannelStatusResponse messages\n        that have been received for this TE link.')
lmpTeChannelStatusRspSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 39), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeChannelStatusRspSent.setDescription('This object counts the number of ChannelStatusResponse messages\n        that have been sent for this TE link.')
lmpTeCounterDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 15, 1, 40), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpTeCounterDiscontinuityTime.setDescription("The value of sysUpTime on the most recent occasion at which\n         one or more of this TE link's counters suffered a\n         discontinuity.  The relevant counters are the specific\n         instances associated with this TE link of any Counter32\n\n\n\n         object contained in the lmpTeLinkPerfTable.  If\n         no such discontinuities have occurred since the last re-\n         initialization of the local management subsystem, then this\n         object contains a zero value.")
lmpDataLinkTable = MibTable((1, 3, 6, 1, 2, 1, 10, 227, 1, 16), )
if mibBuilder.loadTexts: lmpDataLinkTable.setDescription('This table specifies the data-bearing links managed by the\n        LMP.')
lmpDataLinkEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 227, 1, 16, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: lmpDataLinkEntry.setDescription('An entry in this table exists for each ifEntry that represents\n        a data-bearing link.  An ifEntry with an ifIndex must exist\n        before the corresponding lmpDataLinkEntry is created.\n        If an entry representing the data-bearing link is destroyed in\n        the ifTable, then so is the corresponding entry in the\n        lmpDataLinkTable.  The administrative status value is\n        controlled from the ifEntry.  The index to this table is also\n        used to get information in the componentLinkTable\n        of the TE-LINK-STD-MIB MIB module.')
lmpDataLinkType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 16, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("port", 1), ("componentLink", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpDataLinkType.setDescription('This attribute specifies whether this data-bearing link is\n        a port or a component link.  Component links are multiplex\n        capable, whereas ports are not multiplex capable.')
lmpDataLinkAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 16, 1, 2), InetAddressType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpDataLinkAddressType.setDescription('This attribute specifies the data-bearing link IP address\n        type.  If the data-bearing link is unnumbered, the address\n        type must be set to unknown(0).')
lmpDataLinkIpAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 16, 1, 3), InetAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpDataLinkIpAddr.setDescription('The local Internet address for numbered links.  The type\n        of this address is determined by the value of\n        lmpDataLinkAddressType object.\n\n        For IPv4 and IPv6 numbered links, this object represents\n        the local IP address associated with the data-bearing\n        link.  For an unnumbered link, the local address is\n        of type unknown, and this object is set to the zero-length\n        string; the ifIndex object then identifies the\n        unnumbered address.')
lmpDataLinkRemoteIpAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 16, 1, 4), InetAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpDataLinkRemoteIpAddress.setDescription('The remote Internet address for numbered data-bearing links.\n        The type of this address is determined by the\n        lmpDataLinkAddressType object.\n\n        For IPv4 and IPv6 numbered links, this object represents the\n        remote IP address associated with the data-bearing link.  For\n        an unnumbered link, the remote address is of type unknown,\n        and this object is set to the zero-length string; the\n        lmpDataLinkRemoteIfId object then identifies the unnumbered\n        address.\n\n        This information is either configured manually or\n        communicated by the remote node during the link verification\n        procedure.')
lmpDataLinkRemoteIfId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 16, 1, 5), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpDataLinkRemoteIfId.setDescription('Interface identifier of the remote end point.  This\n        information is either configured manually or\n        communicated by the remote node during the link verification\n        procedure.')
lmpDataLinkEncodingType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 16, 1, 6), TeLinkEncodingType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpDataLinkEncodingType.setDescription('The encoding type of the data-bearing link.')
lmpDataLinkActiveOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 16, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("upAlloc", 1), ("upFree", 2), ("down", 3), ("testing", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpDataLinkActiveOperStatus.setDescription('The actual operational status of this data-bearing link\n\n\n\n        (active FSM).')
lmpDataLinkPassiveOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 16, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("upAlloc", 1), ("upFree", 2), ("down", 3), ("psvTst", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpDataLinkPassiveOperStatus.setDescription('The actual operational status of this data-bearing link\n        (passive FSM).')
lmpDataLinkRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 16, 1, 9), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpDataLinkRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  None of the writable objects\n        in a row can be changed if the status is active(1).\n        All read-create objects must have valid and consistent\n        values before the row can be activated.')
lmpDataLinkStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 16, 1, 10), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: lmpDataLinkStorageType.setDescription("The storage type for this conceptual row in the\n        lmpDataLinkTable.  Conceptual rows having the value\n        'permanent' need not allow write-access to any\n        columnar object in the row.")
lmpDataLinkPerfTable = MibTable((1, 3, 6, 1, 2, 1, 10, 227, 1, 17), )
if mibBuilder.loadTexts: lmpDataLinkPerfTable.setDescription('This table specifies the data-bearing links LMP performance\n        counters.')
lmpDataLinkPerfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 227, 1, 17, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: lmpDataLinkPerfEntry.setDescription('An entry in this table contains information about\n        the LMP performance counters for the data-bearing links.\n        lmpDataLinkDiscontinuityTime is used to indicate potential\n        discontinuity for all counter objects in this table.')
lmpDataLinkTestReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 17, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpDataLinkTestReceived.setDescription('This object counts the number of Test messages that have\n        been received on this data-bearing link.')
lmpDataLinkTestSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 17, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpDataLinkTestSent.setDescription('This object counts the number of Test messages that have\n        been sent on this data-bearing link.')
lmpDataLinkActiveTestSuccess = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 17, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpDataLinkActiveTestSuccess.setDescription('This object counts the number of data-bearing link tests\n        that were successful on the active side of this data-\n        bearing link.')
lmpDataLinkActiveTestFailure = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 17, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpDataLinkActiveTestFailure.setDescription('This object counts the number of data-bearing link tests\n        that failed on the active side of this data-bearing link.')
lmpDataLinkPassiveTestSuccess = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 17, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpDataLinkPassiveTestSuccess.setDescription('This object counts the number of data-bearing link tests\n        that were successful on the passive side of this data-\n        bearing link.')
lmpDataLinkPassiveTestFailure = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 17, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpDataLinkPassiveTestFailure.setDescription('This object counts the number of data-bearing link tests\n        that failed on the passive side of this data-bearing link.')
lmpDataLinkDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 227, 1, 17, 1, 7), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lmpDataLinkDiscontinuityTime.setDescription("The value of sysUpTime on the most recent occasion at which\n         one or more of this data-bearing link's counters suffered\n         a discontinuity.  The relevant counters are the specific\n         instances associated with this data-bearing link of any\n         Counter32 object contained in the lmpDataLinkPerfTable.  If\n\n\n\n         no such discontinuities have occurred since the last re-\n         initialization of the local management subsystem, then this\n         object contains a zero value.")
lmpNotificationMaxRate = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 18), Unsigned32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpNotificationMaxRate.setDescription('The LMP notification rate depends on the size of the network,\n        the type of links, the network configuration, the\n        reliability of the network, etc.\n\n        When this MIB was designed, care was taken to minimize the\n        amount of notifications generated for LMP purposes.  Wherever\n        possible, notifications are state driven, meaning that the\n        notifications are sent only when the system changes state.\n        The only notifications that are repeated and that could cause a\n        problem as far as congestion is concerned are the ones\n        associated with data link verification.\n        Without any considerations to handling of these\n        notifications, a problem may arise if the number of data\n        links is high.  Since the data link verification notifications\n        can happen only once per data link per link verification\n        interval, the notification rate should be sustainable if one\n        chooses an appropriate link verification interval for a given\n        network configuration.  For instance, a network of 100 nodes\n        with 5 links of 128 wavelengths each and a link verification\n        of 1 minute, where no more than 10% of the links failed at any\n        given time, would have 1 notification per second sent from\n        each node, or 100 notifications per second for the whole\n        network.  The rest of the notifications are negligible\n        compared to this number.\n\n        To alleviate the congestion problem, the\n        lmpNotificationMaxRate object can be used to implement a\n        throttling mechanism.  It is also possible to enable/disable\n        certain type of notifications.\n\n        This variable indicates the maximum number of\n        notifications issued per minute.  If events occur\n        more rapidly, the implementation may simply fail to\n\n\n\n        emit these notifications during that period or may\n        queue them until an appropriate time.  A value of 0\n        means that no throttling is applied and events may be\n        notified at the rate at which they occur.\n        Implementations should save the value of this object in\n        persistent memory so that it survives restarts or reboot.')
lmpLinkPropertyNotificationsEnabled = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 19), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpLinkPropertyNotificationsEnabled.setDescription('If this object is true(1), then it enables the\n        generation of lmpTeLinkPropertyMismatch\n        and lmpDataLinkPropertyMismatch notifications;\n        otherwise, these notifications are not emitted.\n        Implementations should save the value of this object in\n        persistent memory so that it survives restarts or reboot.')
lmpUnprotectedNotificationsEnabled = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 20), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpUnprotectedNotificationsEnabled.setDescription('If this object is true(1), then it enables the\n        generation of lmpUnprotected notifications;\n        otherwise, these notifications are not emitted.\n        Implementations should save the value of this object in\n        persistent memory so that it survives restarts or reboot.')
lmpCcUpDownNotificationsEnabled = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 21), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpCcUpDownNotificationsEnabled.setDescription('If this object is true(1), then it enables the generation of\n        lmpControlChannelUp and lmpControlChannelDown notifications;\n        otherwise, these notifications are not emitted.\n        Implementations should save the value of this object in\n        persistent memory so that it survives restarts or reboot.')
lmpTeLinkNotificationsEnabled = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 22), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpTeLinkNotificationsEnabled.setDescription('If this object is true(1), then it enables the\n        generation of lmpTeLinkDegraded and lmpTeLinkNotDegraded\n        notifications; otherwise, these notifications are not emitted.\n        Implementations should save the value of this object in\n        persistent memory so that it survives restarts or reboot.')
lmpDataLinkNotificationsEnabled = MibScalar((1, 3, 6, 1, 2, 1, 10, 227, 1, 23), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lmpDataLinkNotificationsEnabled.setDescription('If this object is true(1), then it enables the\n        generation of lmpDataLinkVerificationFailure\n        notification; otherwise, these notifications are not emitted.\n        Implementations should save the value of this object in\n        persistent memory so that it survives restarts or reboot.')
lmpTeLinkPropertyMismatch = NotificationType((1, 3, 6, 1, 2, 1, 10, 227, 0, 1)).setObjects(*(("LMP-MIB", "teLinkRemoteIpAddr"), ("LMP-MIB", "teLinkIncomingIfId"),))
if mibBuilder.loadTexts: lmpTeLinkPropertyMismatch.setDescription('This notification is generated when a TE link property\n        mismatch is detected on the node.  The received remote TE link\n        ID of the misconfigured TE link is represented by either\n        teLinkRemoteIpAddr or teLinkIncomingIfId, depending on whether\n        the TE link is numbered or unnumbered.  This notification\n        should not be sent unless lmpLinkPropertyNotificationsEnabled\n        is true(1).  It is recommended that this notification be\n        reported only the first time a mismatch is detected.\n        Otherwise, for a given TE link, this notification can occur\n        no more than once per verification interval\n        (lmpGlobalLinkVerificationInterval).')
lmpDataLinkPropertyMismatch = NotificationType((1, 3, 6, 1, 2, 1, 10, 227, 0, 2)).setObjects(*(("LMP-MIB", "lmpDataLinkType"), ("LMP-MIB", "lmpDataLinkRemoteIfId"),))
if mibBuilder.loadTexts: lmpDataLinkPropertyMismatch.setDescription('This notification is generated when a data-bearing link\n        property mismatch is detected on the node.  lmpDataLinkType\n        is used to identify the local identifiers associated with\n        the data link.  (The data link interface index can be used\n        to determine the TE link interface index, as this\n        relationship is captured in the interface stack table.)\n        The remote entity interface ID is the remote entity\n        interface ID received in the LinkSummary message.\n        This notification should not be sent unless\n        lmpLinkPropertyNotificationsEnabled is true(1).  It is\n        recommended that this notification be reported only the\n        first time a mismatch is detected.  Otherwise, for a given\n        data link, this notification can occur no more than once\n        per verification interval (lmpGlobalLinkVerificationInterval).')
lmpUnprotected = NotificationType((1, 3, 6, 1, 2, 1, 10, 227, 0, 3)).setObjects(*(("LMP-MIB", "lmpCcNbrNodeId"),))
if mibBuilder.loadTexts: lmpUnprotected.setDescription('This notification is generated when there is more than one\n        control channel between LMP neighbors and the last redundant\n        control channel has failed.  If the remaining operational\n        control channel fails, then there will be no more control\n        channels between the pair of nodes and all the TE links\n        between the pair of nodes, will go to degraded state.  This\n        notification should not be sent unless\n        lmpUnprotectedNotificationsEnabled is set to true(1).')
lmpControlChannelUp = NotificationType((1, 3, 6, 1, 2, 1, 10, 227, 0, 4)).setObjects(*(("LMP-MIB", "lmpCcAdminStatus"), ("LMP-MIB", "lmpCcOperStatus"),))
if mibBuilder.loadTexts: lmpControlChannelUp.setDescription('This notification is generated when a control\n        channel transitions to the up operational state.  This\n        notification should not be sent unless\n        lmpCcUpDownNotificationsEnabled is true(1).')
lmpControlChannelDown = NotificationType((1, 3, 6, 1, 2, 1, 10, 227, 0, 5)).setObjects(*(("LMP-MIB", "lmpCcAdminStatus"), ("LMP-MIB", "lmpCcOperStatus"),))
if mibBuilder.loadTexts: lmpControlChannelDown.setDescription('This notification is generated when a control channel\n        transitions out of the up operational state.  This\n        notification should not be sent unless\n        lmpCcUpDownNotificationsEnabled is true(1).')
lmpTeLinkDegraded = NotificationType((1, 3, 6, 1, 2, 1, 10, 227, 0, 6)).setObjects(*(("LMP-MIB", "lmpTeLinkOperStatus"),))
if mibBuilder.loadTexts: lmpTeLinkDegraded.setDescription('This notification is generated when a lmpTeLinkOperStatus\n        object for a TE link enters the degraded state.  This\n        notification should not be sent unless\n        lmpTeLinkNotificationsEnabled is true(1).')
lmpTeLinkNotDegraded = NotificationType((1, 3, 6, 1, 2, 1, 10, 227, 0, 7)).setObjects(*(("LMP-MIB", "lmpTeLinkOperStatus"),))
if mibBuilder.loadTexts: lmpTeLinkNotDegraded.setDescription('This notification is generated when a lmpTeLinkOperStatus\n        object for a TE link leaves the degraded state.  This\n        notification should not be sent unless\n        lmpTeLinkNotificationsEnabled is true(1).')
lmpDataLinkVerificationFailure = NotificationType((1, 3, 6, 1, 2, 1, 10, 227, 0, 8)).setObjects(*(("LMP-MIB", "lmpDataLinkActiveOperStatus"), ("LMP-MIB", "lmpDataLinkPassiveOperStatus"),))
if mibBuilder.loadTexts: lmpDataLinkVerificationFailure.setDescription('This notification is generated when a data-bearing\n        link verification fails.  This notification should not be sent\n        unless lmpDataLinkNotificationsEnabled is true(1).  For a given\n        data link, this notification can occur no more than once per\n        verification interval (lmpGlobalLinkVerificationInterval).')
lmpCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 227, 2, 1))
lmpGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 227, 2, 2))
lmpModuleFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 227, 2, 1, 1)).setObjects(*(("LMP-MIB", "lmpNodeGroup"), ("LMP-MIB", "lmpControlChannelGroup"), ("LMP-MIB", "lmpLinkPropertyCorrelationGroup"), ("LMP-MIB", "lmpPerfGroup"), ("LMP-MIB", "lmpTeLinkGroup"), ("LMP-MIB", "lmpDataLinkGroup"), ("LMP-MIB", "lmpCcIsNotInterfaceGroup"), ("LMP-MIB", "lmpCcIsInterfaceGroup"), ("LMP-MIB", "lmpLinkVerificationGroup"), ("LMP-MIB", "lmpNotificationGroup"),))
if mibBuilder.loadTexts: lmpModuleFullCompliance.setDescription('Compliance statement for agents that support the\n        configuration and monitoring of LMP MIB.')
lmpModuleReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 227, 2, 1, 2)).setObjects(*(("LMP-MIB", "lmpNodeGroup"), ("LMP-MIB", "lmpControlChannelGroup"), ("LMP-MIB", "lmpLinkPropertyCorrelationGroup"), ("LMP-MIB", "lmpPerfGroup"), ("LMP-MIB", "lmpTeLinkGroup"), ("LMP-MIB", "lmpDataLinkGroup"), ("LMP-MIB", "lmpCcIsNotInterfaceGroup"), ("LMP-MIB", "lmpCcIsInterfaceGroup"), ("LMP-MIB", "lmpLinkVerificationGroup"), ("LMP-MIB", "lmpNotificationGroup"),))
if mibBuilder.loadTexts: lmpModuleReadOnlyCompliance.setDescription('Compliance statement for agents that support the\n        monitoring of the LMP MIB.')
lmpNodeGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 227, 2, 2, 1)).setObjects(*(("LMP-MIB", "lmpAdminStatus"), ("LMP-MIB", "lmpOperStatus"), ("LMP-MIB", "lmpNbrAdminStatus"), ("LMP-MIB", "lmpNbrOperStatus"), ("LMP-MIB", "lmpNbrRowStatus"), ("LMP-MIB", "lmpNbrStorageType"), ("LMP-MIB", "lmpUnprotectedNotificationsEnabled"), ("LMP-MIB", "lmpNotificationMaxRate"),))
if mibBuilder.loadTexts: lmpNodeGroup.setDescription('Collection of objects that represent LMP node\n           configuration.')
lmpControlChannelGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 227, 2, 2, 2)).setObjects(*(("LMP-MIB", "lmpNbrRetransmitInterval"), ("LMP-MIB", "lmpNbrRetryLimit"), ("LMP-MIB", "lmpNbrRetransmitDelta"), ("LMP-MIB", "lmpNbrAdminStatus"), ("LMP-MIB", "lmpNbrOperStatus"), ("LMP-MIB", "lmpNbrRowStatus"), ("LMP-MIB", "lmpNbrStorageType"), ("LMP-MIB", "lmpCcHelloIntervalDefault"), ("LMP-MIB", "lmpCcHelloIntervalDefaultMin"), ("LMP-MIB", "lmpCcHelloIntervalDefaultMax"), ("LMP-MIB", "lmpCcHelloDeadIntervalDefault"), ("LMP-MIB", "lmpCcHelloDeadIntervalDefaultMin"), ("LMP-MIB", "lmpCcHelloDeadIntervalDefaultMax"), ("LMP-MIB", "lmpCcNbrNodeId"), ("LMP-MIB", "lmpCcRemoteId"), ("LMP-MIB", "lmpCcRemoteAddressType"), ("LMP-MIB", "lmpCcRemoteIpAddr"), ("LMP-MIB", "lmpCcSetupRole"), ("LMP-MIB", "lmpCcAuthentication"), ("LMP-MIB", "lmpCcHelloInterval"), ("LMP-MIB", "lmpCcHelloIntervalMin"), ("LMP-MIB", "lmpCcHelloIntervalMax"), ("LMP-MIB", "lmpCcHelloIntervalNegotiated"), ("LMP-MIB", "lmpCcHelloDeadInterval"), ("LMP-MIB", "lmpCcHelloDeadIntervalMin"), ("LMP-MIB", "lmpCcHelloDeadIntervalMax"), ("LMP-MIB", "lmpCcHelloDeadIntervalNegotiated"), ("LMP-MIB", "lmpCcOperStatus"), ("LMP-MIB", "lmpCcRowStatus"), ("LMP-MIB", "lmpCcStorageType"), ("LMP-MIB", "lmpCcUpDownNotificationsEnabled"),))
if mibBuilder.loadTexts: lmpControlChannelGroup.setDescription('Objects that can be used to configure LMP interface.')
lmpCcIsInterfaceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 227, 2, 2, 3)).setObjects(*(("LMP-MIB", "lmpCcIsIf"),))
if mibBuilder.loadTexts: lmpCcIsInterfaceGroup.setDescription('Objects that can be used to configure control channels\n           that are interfaces.')
lmpCcIsNotInterfaceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 227, 2, 2, 4)).setObjects(*(("LMP-MIB", "lmpCcUnderlyingIfIndex"), ("LMP-MIB", "lmpCcIsIf"), ("LMP-MIB", "lmpCcLastChange"), ("LMP-MIB", "lmpCcAdminStatus"),))
if mibBuilder.loadTexts: lmpCcIsNotInterfaceGroup.setDescription('Objects that can be used to configure control channels\n           that are not interfaces.')
lmpLinkPropertyCorrelationGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 227, 2, 2, 5)).setObjects(*(("LMP-MIB", "lmpLinkPropertyNotificationsEnabled"),))
if mibBuilder.loadTexts: lmpLinkPropertyCorrelationGroup.setDescription('Collection of objects used to configure the link\n           property correlation procedure.')
lmpLinkVerificationGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 227, 2, 2, 6)).setObjects(*(("LMP-MIB", "lmpGlobalLinkVerificationInterval"), ("LMP-MIB", "lmpLinkVerifyInterval"), ("LMP-MIB", "lmpLinkVerifyDeadInterval"), ("LMP-MIB", "lmpLinkVerifyTransportMechanism"), ("LMP-MIB", "lmpLinkVerifyAllLinks"), ("LMP-MIB", "lmpLinkVerifyTransmissionRate"), ("LMP-MIB", "lmpLinkVerifyWavelength"), ("LMP-MIB", "lmpLinkVerifyRowStatus"), ("LMP-MIB", "lmpLinkVerifyStorageType"), ("LMP-MIB", "lmpDataLinkNotificationsEnabled"),))
if mibBuilder.loadTexts: lmpLinkVerificationGroup.setDescription('Collection of objects that represent the link\n           verification procedure configuration.')
lmpPerfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 227, 2, 2, 7)).setObjects(*(("LMP-MIB", "lmpCcInOctets"), ("LMP-MIB", "lmpCcInDiscards"), ("LMP-MIB", "lmpCcInErrors"), ("LMP-MIB", "lmpCcOutOctets"), ("LMP-MIB", "lmpCcOutDiscards"), ("LMP-MIB", "lmpCcOutErrors"), ("LMP-MIB", "lmpCcConfigReceived"), ("LMP-MIB", "lmpCcConfigSent"), ("LMP-MIB", "lmpCcConfigRetransmit"), ("LMP-MIB", "lmpCcConfigAckReceived"), ("LMP-MIB", "lmpCcConfigAckSent"), ("LMP-MIB", "lmpCcConfigNackSent"), ("LMP-MIB", "lmpCcConfigNackReceived"), ("LMP-MIB", "lmpCcHelloReceived"), ("LMP-MIB", "lmpCcHelloSent"), ("LMP-MIB", "lmpCcBeginVerifyReceived"), ("LMP-MIB", "lmpCcBeginVerifySent"), ("LMP-MIB", "lmpCcBeginVerifyRetransmit"), ("LMP-MIB", "lmpCcBeginVerifyAckReceived"), ("LMP-MIB", "lmpCcBeginVerifyAckSent"), ("LMP-MIB", "lmpCcBeginVerifyNackReceived"), ("LMP-MIB", "lmpCcBeginVerifyNackSent"), ("LMP-MIB", "lmpCcEndVerifyReceived"), ("LMP-MIB", "lmpCcEndVerifySent"), ("LMP-MIB", "lmpCcEndVerifyRetransmit"), ("LMP-MIB", "lmpCcEndVerifyAckReceived"), ("LMP-MIB", "lmpCcEndVerifyAckSent"), ("LMP-MIB", "lmpCcTestStatusSuccessReceived"), ("LMP-MIB", "lmpCcTestStatusSuccessSent"), ("LMP-MIB", "lmpCcTestStatusSuccessRetransmit"), ("LMP-MIB", "lmpCcTestStatusFailureReceived"), ("LMP-MIB", "lmpCcTestStatusFailureSent"), ("LMP-MIB", "lmpCcTestStatusFailureRetransmit"), ("LMP-MIB", "lmpCcTestStatusAckReceived"), ("LMP-MIB", "lmpCcTestStatusAckSent"), ("LMP-MIB", "lmpCcLinkSummaryReceived"), ("LMP-MIB", "lmpCcLinkSummarySent"), ("LMP-MIB", "lmpCcLinkSummaryRetransmit"), ("LMP-MIB", "lmpCcLinkSummaryAckReceived"), ("LMP-MIB", "lmpCcLinkSummaryAckSent"), ("LMP-MIB", "lmpCcLinkSummaryNackReceived"), ("LMP-MIB", "lmpCcLinkSummaryNackSent"), ("LMP-MIB", "lmpCcChannelStatusReceived"), ("LMP-MIB", "lmpCcChannelStatusSent"), ("LMP-MIB", "lmpCcChannelStatusRetransmit"), ("LMP-MIB", "lmpCcChannelStatusAckReceived"), ("LMP-MIB", "lmpCcChannelStatusAckSent"), ("LMP-MIB", "lmpCcChannelStatusReqReceived"), ("LMP-MIB", "lmpCcChannelStatusReqSent"), ("LMP-MIB", "lmpCcChannelStatusReqRetransmit"), ("LMP-MIB", "lmpCcChannelStatusRspReceived"), ("LMP-MIB", "lmpCcChannelStatusRspSent"), ("LMP-MIB", "lmpCcCounterDiscontinuityTime"), ("LMP-MIB", "lmpTeInOctets"), ("LMP-MIB", "lmpTeOutOctets"), ("LMP-MIB", "lmpTeBeginVerifyReceived"), ("LMP-MIB", "lmpTeBeginVerifySent"), ("LMP-MIB", "lmpTeBeginVerifyRetransmit"), ("LMP-MIB", "lmpTeBeginVerifyAckReceived"), ("LMP-MIB", "lmpTeBeginVerifyAckSent"), ("LMP-MIB", "lmpTeBeginVerifyNackReceived"), ("LMP-MIB", "lmpTeBeginVerifyNackSent"), ("LMP-MIB", "lmpTeEndVerifyReceived"), ("LMP-MIB", "lmpTeEndVerifySent"), ("LMP-MIB", "lmpTeEndVerifyRetransmit"), ("LMP-MIB", "lmpTeEndVerifyAckReceived"), ("LMP-MIB", "lmpTeEndVerifyAckSent"), ("LMP-MIB", "lmpTeTestStatusSuccessReceived"), ("LMP-MIB", "lmpTeTestStatusSuccessSent"), ("LMP-MIB", "lmpTeTestStatusSuccessRetransmit"), ("LMP-MIB", "lmpTeTestStatusFailureReceived"), ("LMP-MIB", "lmpTeTestStatusFailureSent"), ("LMP-MIB", "lmpTeTestStatusFailureRetransmit"), ("LMP-MIB", "lmpTeTestStatusAckReceived"), ("LMP-MIB", "lmpTeTestStatusAckSent"), ("LMP-MIB", "lmpTeLinkSummaryReceived"), ("LMP-MIB", "lmpTeLinkSummarySent"), ("LMP-MIB", "lmpTeLinkSummaryRetransmit"), ("LMP-MIB", "lmpTeLinkSummaryAckReceived"), ("LMP-MIB", "lmpTeLinkSummaryAckSent"), ("LMP-MIB", "lmpTeLinkSummaryNackReceived"), ("LMP-MIB", "lmpTeLinkSummaryNackSent"), ("LMP-MIB", "lmpTeChannelStatusReceived"), ("LMP-MIB", "lmpTeChannelStatusSent"), ("LMP-MIB", "lmpTeChannelStatusRetransmit"), ("LMP-MIB", "lmpTeChannelStatusAckReceived"), ("LMP-MIB", "lmpTeChannelStatusAckSent"), ("LMP-MIB", "lmpTeChannelStatusReqReceived"), ("LMP-MIB", "lmpTeChannelStatusReqSent"), ("LMP-MIB", "lmpTeChannelStatusReqRetransmit"), ("LMP-MIB", "lmpTeChannelStatusRspSent"), ("LMP-MIB", "lmpTeChannelStatusRspReceived"), ("LMP-MIB", "lmpTeCounterDiscontinuityTime"), ("LMP-MIB", "lmpDataLinkTestReceived"), ("LMP-MIB", "lmpDataLinkTestSent"), ("LMP-MIB", "lmpDataLinkActiveTestSuccess"), ("LMP-MIB", "lmpDataLinkActiveTestFailure"), ("LMP-MIB", "lmpDataLinkPassiveTestSuccess"), ("LMP-MIB", "lmpDataLinkPassiveTestFailure"), ("LMP-MIB", "lmpDataLinkDiscontinuityTime"),))
if mibBuilder.loadTexts: lmpPerfGroup.setDescription('Collection of objects used to provide performance\n           information about LMP interfaces and data-bearing links.')
lmpTeLinkGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 227, 2, 2, 8)).setObjects(*(("LMP-MIB", "lmpTeLinkNbrRemoteNodeId"), ("LMP-MIB", "lmpTeLinkVerification"), ("LMP-MIB", "lmpTeLinkFaultManagement"), ("LMP-MIB", "lmpTeLinkDwdm"), ("LMP-MIB", "lmpTeLinkOperStatus"), ("LMP-MIB", "lmpTeLinkRowStatus"), ("LMP-MIB", "lmpTeLinkStorageType"), ("LMP-MIB", "lmpTeLinkNotificationsEnabled"),))
if mibBuilder.loadTexts: lmpTeLinkGroup.setDescription('Objects that can be used to configure TE links.')
lmpDataLinkGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 227, 2, 2, 9)).setObjects(*(("LMP-MIB", "lmpDataLinkType"), ("LMP-MIB", "lmpDataLinkAddressType"), ("LMP-MIB", "lmpDataLinkIpAddr"), ("LMP-MIB", "lmpDataLinkRemoteIpAddress"), ("LMP-MIB", "lmpDataLinkRemoteIfId"), ("LMP-MIB", "lmpDataLinkEncodingType"), ("LMP-MIB", "lmpDataLinkActiveOperStatus"), ("LMP-MIB", "lmpDataLinkPassiveOperStatus"), ("LMP-MIB", "lmpDataLinkRowStatus"), ("LMP-MIB", "lmpDataLinkStorageType"),))
if mibBuilder.loadTexts: lmpDataLinkGroup.setDescription('Collection of objects that represent data-bearing link\n           configuration.')
lmpNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 227, 2, 2, 10)).setObjects(*(("LMP-MIB", "lmpTeLinkPropertyMismatch"), ("LMP-MIB", "lmpDataLinkPropertyMismatch"), ("LMP-MIB", "lmpUnprotected"), ("LMP-MIB", "lmpControlChannelUp"), ("LMP-MIB", "lmpControlChannelDown"), ("LMP-MIB", "lmpTeLinkDegraded"), ("LMP-MIB", "lmpTeLinkNotDegraded"), ("LMP-MIB", "lmpDataLinkVerificationFailure"),))
if mibBuilder.loadTexts: lmpNotificationGroup.setDescription('Set of notifications defined in this module.')
mibBuilder.exportSymbols("LMP-MIB", LmpInterval=LmpInterval, lmpCcBeginVerifyReceived=lmpCcBeginVerifyReceived, lmpCcLinkSummaryRetransmit=lmpCcLinkSummaryRetransmit, lmpTeLinkRowStatus=lmpTeLinkRowStatus, lmpGlobalLinkVerificationInterval=lmpGlobalLinkVerificationInterval, lmpCcOperStatus=lmpCcOperStatus, lmpDataLinkEncodingType=lmpDataLinkEncodingType, lmpCcLinkSummarySent=lmpCcLinkSummarySent, lmpDataLinkTable=lmpDataLinkTable, lmpCcConfigReceived=lmpCcConfigReceived, lmpTeEndVerifyReceived=lmpTeEndVerifyReceived, lmpNbrTable=lmpNbrTable, lmpCcRemoteId=lmpCcRemoteId, lmpCcHelloDeadIntervalMax=lmpCcHelloDeadIntervalMax, lmpTeInOctets=lmpTeInOctets, lmpTeEndVerifyAckReceived=lmpTeEndVerifyAckReceived, lmpCcConfigRetransmit=lmpCcConfigRetransmit, lmpCcChannelStatusAckReceived=lmpCcChannelStatusAckReceived, lmpTeTestStatusFailureRetransmit=lmpTeTestStatusFailureRetransmit, lmpDataLinkDiscontinuityTime=lmpDataLinkDiscontinuityTime, lmpTeBeginVerifyRetransmit=lmpTeBeginVerifyRetransmit, lmpCcOutErrors=lmpCcOutErrors, lmpTeLinkTable=lmpTeLinkTable, lmpCcBeginVerifyNackReceived=lmpCcBeginVerifyNackReceived, lmpCcBeginVerifySent=lmpCcBeginVerifySent, lmpCcOutOctets=lmpCcOutOctets, lmpNbrRowStatus=lmpNbrRowStatus, lmpCcIsIf=lmpCcIsIf, lmpCcNbrNodeId=lmpCcNbrNodeId, LmpRetransmitInterval=LmpRetransmitInterval, lmpCcHelloDeadIntervalMin=lmpCcHelloDeadIntervalMin, lmpDataLinkPropertyMismatch=lmpDataLinkPropertyMismatch, lmpDataLinkEntry=lmpDataLinkEntry, lmpTeChannelStatusRspReceived=lmpTeChannelStatusRspReceived, lmpTeTestStatusAckSent=lmpTeTestStatusAckSent, lmpControlChannelDown=lmpControlChannelDown, lmpCcInDiscards=lmpCcInDiscards, lmpDataLinkPerfEntry=lmpDataLinkPerfEntry, lmpCcChannelStatusRspReceived=lmpCcChannelStatusRspReceived, lmpTeTestStatusSuccessRetransmit=lmpTeTestStatusSuccessRetransmit, lmpCcTestStatusSuccessSent=lmpCcTestStatusSuccessSent, lmpTeLinkSummaryAckSent=lmpTeLinkSummaryAckSent, lmpCcHelloIntervalMax=lmpCcHelloIntervalMax, lmpTeChannelStatusReqRetransmit=lmpTeChannelStatusReqRetransmit, lmpDataLinkActiveTestFailure=lmpDataLinkActiveTestFailure, PYSNMP_MODULE_ID=lmpMIB, lmpCcChannelStatusReqReceived=lmpCcChannelStatusReqReceived, lmpNotifications=lmpNotifications, lmpTeBeginVerifyNackSent=lmpTeBeginVerifyNackSent, lmpCcAuthentication=lmpCcAuthentication, lmpCcRowStatus=lmpCcRowStatus, lmpModuleReadOnlyCompliance=lmpModuleReadOnlyCompliance, lmpCcIsNotInterfaceGroup=lmpCcIsNotInterfaceGroup, lmpLinkVerifyRowStatus=lmpLinkVerifyRowStatus, lmpDataLinkPassiveOperStatus=lmpDataLinkPassiveOperStatus, lmpNbrEntry=lmpNbrEntry, lmpDataLinkActiveOperStatus=lmpDataLinkActiveOperStatus, lmpCcBeginVerifyNackSent=lmpCcBeginVerifyNackSent, lmpConformance=lmpConformance, lmpCcSetupRole=lmpCcSetupRole, lmpCcHelloIntervalNegotiated=lmpCcHelloIntervalNegotiated, lmpCcIsInterfaceGroup=lmpCcIsInterfaceGroup, lmpCcBeginVerifyAckReceived=lmpCcBeginVerifyAckReceived, lmpControlChannelPerfEntry=lmpControlChannelPerfEntry, lmpTeBeginVerifyAckReceived=lmpTeBeginVerifyAckReceived, lmpPerfGroup=lmpPerfGroup, lmpNbrStorageType=lmpNbrStorageType, lmpCcConfigAckSent=lmpCcConfigAckSent, lmpOperStatus=lmpOperStatus, lmpNbrRetransmitInterval=lmpNbrRetransmitInterval, lmpLinkVerifyWavelength=lmpLinkVerifyWavelength, lmpTeChannelStatusReqReceived=lmpTeChannelStatusReqReceived, lmpTeLinkNotificationsEnabled=lmpTeLinkNotificationsEnabled, lmpLinkVerifyStorageType=lmpLinkVerifyStorageType, lmpTeTestStatusFailureReceived=lmpTeTestStatusFailureReceived, lmpObjects=lmpObjects, lmpCcConfigNackReceived=lmpCcConfigNackReceived, lmpDataLinkTestReceived=lmpDataLinkTestReceived, lmpTeLinkOperStatus=lmpTeLinkOperStatus, lmpControlChannelEntry=lmpControlChannelEntry, lmpCcHelloSent=lmpCcHelloSent, lmpCcChannelStatusReceived=lmpCcChannelStatusReceived, lmpTeEndVerifyAckSent=lmpTeEndVerifyAckSent, lmpCcBeginVerifyAckSent=lmpCcBeginVerifyAckSent, lmpUnprotectedNotificationsEnabled=lmpUnprotectedNotificationsEnabled, lmpTeBeginVerifySent=lmpTeBeginVerifySent, lmpCcConfigSent=lmpCcConfigSent, lmpTeLinkSummaryAckReceived=lmpTeLinkSummaryAckReceived, lmpTeLinkDegraded=lmpTeLinkDegraded, lmpCcHelloDeadIntervalDefault=lmpCcHelloDeadIntervalDefault, lmpTeEndVerifyRetransmit=lmpTeEndVerifyRetransmit, lmpDataLinkNotificationsEnabled=lmpDataLinkNotificationsEnabled, lmpDataLinkGroup=lmpDataLinkGroup, lmpCcInOctets=lmpCcInOctets, lmpTeLinkNbrRemoteNodeId=lmpTeLinkNbrRemoteNodeId, lmpLinkVerificationEntry=lmpLinkVerificationEntry, lmpTeChannelStatusReqSent=lmpTeChannelStatusReqSent, lmpCcEndVerifyAckSent=lmpCcEndVerifyAckSent, lmpNodeGroup=lmpNodeGroup, lmpCcLinkSummaryAckReceived=lmpCcLinkSummaryAckReceived, lmpDataLinkPassiveTestSuccess=lmpDataLinkPassiveTestSuccess, lmpCcChannelStatusRspSent=lmpCcChannelStatusRspSent, lmpCcTestStatusAckReceived=lmpCcTestStatusAckReceived, lmpCcEndVerifySent=lmpCcEndVerifySent, lmpCcChannelStatusAckSent=lmpCcChannelStatusAckSent, lmpCcLinkSummaryAckSent=lmpCcLinkSummaryAckSent, lmpCcTestStatusFailureRetransmit=lmpCcTestStatusFailureRetransmit, lmpLinkVerifyTransportMechanism=lmpLinkVerifyTransportMechanism, lmpTeLinkNotDegraded=lmpTeLinkNotDegraded, lmpCcTestStatusFailureSent=lmpCcTestStatusFailureSent, lmpTeTestStatusFailureSent=lmpTeTestStatusFailureSent, lmpTeLinkPerfTable=lmpTeLinkPerfTable, LmpNodeId=LmpNodeId, lmpNbrAdminStatus=lmpNbrAdminStatus, lmpNbrRetryLimit=lmpNbrRetryLimit, lmpTeEndVerifySent=lmpTeEndVerifySent, lmpCcUpDownNotificationsEnabled=lmpCcUpDownNotificationsEnabled, lmpDataLinkActiveTestSuccess=lmpDataLinkActiveTestSuccess, lmpCcLastChange=lmpCcLastChange, lmpControlChannelPerfTable=lmpControlChannelPerfTable, lmpLinkVerificationTable=lmpLinkVerificationTable, lmpDataLinkIpAddr=lmpDataLinkIpAddr, lmpDataLinkTestSent=lmpDataLinkTestSent, lmpCcId=lmpCcId, lmpMIB=lmpMIB, lmpNotificationMaxRate=lmpNotificationMaxRate, lmpCcRemoteIpAddr=lmpCcRemoteIpAddr, lmpControlChannelTable=lmpControlChannelTable, lmpCcCounterDiscontinuityTime=lmpCcCounterDiscontinuityTime, lmpTeTestStatusSuccessSent=lmpTeTestStatusSuccessSent, lmpNbrRetransmitDelta=lmpNbrRetransmitDelta, lmpTeBeginVerifyReceived=lmpTeBeginVerifyReceived, lmpCcChannelStatusReqSent=lmpCcChannelStatusReqSent, lmpLinkVerifyDeadInterval=lmpLinkVerifyDeadInterval, lmpCcEndVerifyRetransmit=lmpCcEndVerifyRetransmit, lmpUnprotected=lmpUnprotected, lmpDataLinkRemoteIfId=lmpDataLinkRemoteIfId, lmpTeChannelStatusSent=lmpTeChannelStatusSent, lmpCcTestStatusSuccessReceived=lmpCcTestStatusSuccessReceived, lmpTeLinkPropertyMismatch=lmpTeLinkPropertyMismatch, lmpLinkVerifyTransmissionRate=lmpLinkVerifyTransmissionRate, lmpCcConfigAckReceived=lmpCcConfigAckReceived, lmpCcHelloIntervalMin=lmpCcHelloIntervalMin, lmpDataLinkVerificationFailure=lmpDataLinkVerificationFailure, lmpCcHelloIntervalDefaultMax=lmpCcHelloIntervalDefaultMax, lmpCompliances=lmpCompliances, lmpGroups=lmpGroups, lmpCcAdminStatus=lmpCcAdminStatus, lmpTeLinkSummaryNackReceived=lmpTeLinkSummaryNackReceived, lmpDataLinkPerfTable=lmpDataLinkPerfTable, lmpLinkPropertyCorrelationGroup=lmpLinkPropertyCorrelationGroup, lmpTeBeginVerifyNackReceived=lmpTeBeginVerifyNackReceived, lmpCcOutDiscards=lmpCcOutDiscards, lmpTeLinkPerfEntry=lmpTeLinkPerfEntry, lmpTeTestStatusSuccessReceived=lmpTeTestStatusSuccessReceived, lmpCcUnderlyingIfIndex=lmpCcUnderlyingIfIndex, lmpNbrOperStatus=lmpNbrOperStatus, lmpTeLinkSummaryNackSent=lmpTeLinkSummaryNackSent, lmpCcChannelStatusReqRetransmit=lmpCcChannelStatusReqRetransmit, lmpCcHelloIntervalDefault=lmpCcHelloIntervalDefault, lmpTeLinkDwdm=lmpTeLinkDwdm, lmpTeLinkVerification=lmpTeLinkVerification, lmpTeLinkSummaryRetransmit=lmpTeLinkSummaryRetransmit, lmpDataLinkRemoteIpAddress=lmpDataLinkRemoteIpAddress, lmpModuleFullCompliance=lmpModuleFullCompliance, lmpLinkVerifyAllLinks=lmpLinkVerifyAllLinks, lmpCcConfigNackSent=lmpCcConfigNackSent, lmpCcBeginVerifyRetransmit=lmpCcBeginVerifyRetransmit, lmpCcTestStatusAckSent=lmpCcTestStatusAckSent, lmpTeLinkSummarySent=lmpTeLinkSummarySent, lmpTeLinkGroup=lmpTeLinkGroup, lmpCcHelloReceived=lmpCcHelloReceived, lmpDataLinkStorageType=lmpDataLinkStorageType, lmpDataLinkPassiveTestFailure=lmpDataLinkPassiveTestFailure, lmpCcHelloDeadIntervalDefaultMin=lmpCcHelloDeadIntervalDefaultMin, lmpTeOutOctets=lmpTeOutOctets, lmpNbrNodeId=lmpNbrNodeId, lmpTeLinkSummaryReceived=lmpTeLinkSummaryReceived, lmpLinkVerificationGroup=lmpLinkVerificationGroup, lmpNotificationGroup=lmpNotificationGroup, lmpTeChannelStatusReceived=lmpTeChannelStatusReceived, lmpCcTestStatusSuccessRetransmit=lmpCcTestStatusSuccessRetransmit, lmpDataLinkAddressType=lmpDataLinkAddressType, lmpTeChannelStatusAckReceived=lmpTeChannelStatusAckReceived, lmpAdminStatus=lmpAdminStatus, lmpCcEndVerifyAckReceived=lmpCcEndVerifyAckReceived, lmpCcHelloDeadInterval=lmpCcHelloDeadInterval, lmpCcEndVerifyReceived=lmpCcEndVerifyReceived, lmpCcLinkSummaryReceived=lmpCcLinkSummaryReceived, lmpTeLinkFaultManagement=lmpTeLinkFaultManagement, lmpLinkPropertyNotificationsEnabled=lmpLinkPropertyNotificationsEnabled, lmpDataLinkRowStatus=lmpDataLinkRowStatus, lmpCcHelloDeadIntervalDefaultMax=lmpCcHelloDeadIntervalDefaultMax, lmpTeLinkEntry=lmpTeLinkEntry, lmpTeCounterDiscontinuityTime=lmpTeCounterDiscontinuityTime, lmpDataLinkType=lmpDataLinkType, lmpCcHelloIntervalDefaultMin=lmpCcHelloIntervalDefaultMin, lmpCcLinkSummaryNackReceived=lmpCcLinkSummaryNackReceived, lmpTeTestStatusAckReceived=lmpTeTestStatusAckReceived, lmpLinkVerifyInterval=lmpLinkVerifyInterval, lmpCcChannelStatusSent=lmpCcChannelStatusSent, lmpCcLinkSummaryNackSent=lmpCcLinkSummaryNackSent, lmpTeBeginVerifyAckSent=lmpTeBeginVerifyAckSent, lmpTeChannelStatusRspSent=lmpTeChannelStatusRspSent, lmpControlChannelGroup=lmpControlChannelGroup, lmpCcHelloDeadIntervalNegotiated=lmpCcHelloDeadIntervalNegotiated, lmpTeLinkStorageType=lmpTeLinkStorageType, lmpTeChannelStatusRetransmit=lmpTeChannelStatusRetransmit, lmpCcRemoteAddressType=lmpCcRemoteAddressType, lmpCcStorageType=lmpCcStorageType, lmpTeChannelStatusAckSent=lmpTeChannelStatusAckSent, lmpControlChannelUp=lmpControlChannelUp, lmpCcChannelStatusRetransmit=lmpCcChannelStatusRetransmit, lmpCcInErrors=lmpCcInErrors, lmpCcTestStatusFailureReceived=lmpCcTestStatusFailureReceived, lmpCcHelloInterval=lmpCcHelloInterval)



#
# PySNMP MIB module SIP-MIB-SMI (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/SIP-MIB-SMI
# Produced by pysmi-0.0.7 at Sun Feb 14 00:28:08 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, SingleValueConstraint, ConstraintsUnion, ValueRangeConstraint, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "SingleValueConstraint", "ConstraintsUnion", "ValueRangeConstraint", "ValueSizeConstraint")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( TimeTicks, Counter32, iso, Unsigned32, Counter64, IpAddress, mib_2, ModuleIdentity, Gauge32, Integer32, Bits, ObjectIdentity, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, ) = mibBuilder.importSymbols("SNMPv2-SMI", "TimeTicks", "Counter32", "iso", "Unsigned32", "Counter64", "IpAddress", "mib-2", "ModuleIdentity", "Gauge32", "Integer32", "Bits", "ObjectIdentity", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "NotificationType")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
sipMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 9998))
if mibBuilder.loadTexts: sipMIB.setLastUpdated('200007080000Z')
if mibBuilder.loadTexts: sipMIB.setOrganization('IETF SIP Working Group, SIP MIB Team')
if mibBuilder.loadTexts: sipMIB.setContactInfo('SIP MIB Team email: sip-mib@egroups.com \n\n                 Co-editor  Kevin Lingle \n                            Cisco Systems, Inc. \n                 postal:    7025 Kit Creek Road \n\nLingle/Maeng/Walker                                                  5 \nInternet Draft            SIP-MIB                          July, 2000 \n\n                            P.O. Box 14987 \n                            Research Triangle Park, NC 27709 \n                            USA \n                 email:     klingle@cisco.com \n                 phone:     +1-919-392-2029 \n\n                 Co-editor  Joon Maeng \n                            VTEL Corporation \n                 postal:    108 Wild Basin Rd. \n                            Austin, TX 78746 \n                            USA \n                 email:     joon_maeng@vtel.com \n                 phone:     +1-512-437-4567 \n\n                 Co-editor  Dave Walker \n                            SS8 Networks, Inc. \n                 postal:    80 Hines Road \n                            Kanata, ON  K2K 2T8 \n                            Canada \n                 email:     drwalker@ss8networks.com \n                 phone:     +1 613 592 2100')
if mibBuilder.loadTexts: sipMIB.setDescription('Initial version of Session Initiation Protocol (SIP) \n                 MIB module that defines base OID for all other \n                 SIP-related MIB Modules.')
mibBuilder.exportSymbols("SIP-MIB-SMI", sipMIB=sipMIB, PYSNMP_MODULE_ID=sipMIB)
